var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { EVMContractAddress, SnickerdoodleWalletContractError, WebauthnCredentialId, P256PublicKeyComponents, InvalidParametersError, P256PublicKeyPointX, P256PublicKeyPointY, } from "@snickerdoodlelabs/objects";
import { injectable } from "inversify";
import { err, ok, ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { P256VerificationData, ContractsAbis, } from "../interfaces/objects/index.js";
let SnickerdoodleWalletContract = class SnickerdoodleWalletContract extends BaseContract {
    constructor(providerOrSigner, contractAddress) {
        super(providerOrSigner, contractAddress, ContractsAbis.SnickerdoodleWalletAbi.abi);
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
    }
    factoryAddress() {
        return ResultAsync.fromPromise(this.contract.getFactory(), (e) => {
            return this.generateError(e, "Unable to call getFactory()");
        });
    }
    operatorAddress() {
        return ResultAsync.fromPromise(this.contract.getOperator(), (e) => {
            return this.generateError(e, "Unable to call getOperator()");
        });
    }
    addP256KeyWithP256Key(keyId, authenticatorData, clientDataJSON, newP256Key, p256Signature, overrides) {
        return this.writeToContract("addP256KeyWithP256Key", [
            keyId,
            new P256VerificationData(authenticatorData, clientDataJSON.clientDataJSONLeft, clientDataJSON.clientDataJSONRight),
            newP256Key,
            p256Signature,
        ], overrides);
    }
    static generateAddP256KeyWithP256KeyChallenge(newKeyId, newP256PublicKey) {
        // Convert keyid to Uint8Array (UTF-8 encoding)
        const uint8keyId = new TextEncoder().encode(newKeyId);
        // Convert qx and qy from hex string to Uint8Array
        const uint8qx = new Uint8Array(newP256PublicKey.x
            .slice(2)
            .match(/.{1,2}/g)
            ?.map((byte) => parseInt(byte, 16)) ?? []);
        const uint8qy = new Uint8Array(newP256PublicKey.y
            .slice(2)
            .match(/.{1,2}/g)
            ?.map((byte) => parseInt(byte, 16)) ?? []);
        if (uint8qx.length == 0 || uint8qy.length == 0) {
            return err(new InvalidParametersError("Invalid P256PublicKeyComponents"));
        }
        // Combine all Uint8Arrays into a single Uint8Array
        const totalLength = uint8keyId.length + uint8qx.length + uint8qy.length;
        const payload = new Uint8Array(totalLength);
        payload.set(uint8keyId, 0);
        payload.set(uint8qx, uint8keyId.length);
        payload.set(uint8qy, uint8keyId.length + uint8qx.length);
        return ok(payload);
    }
    addEVMAddressWithP256Key(keyId, authenticatorData, clientDataJSON, evmAccount, p256Signature, overrides) {
        return this.writeToContract("addEVMAddressWithP256Key", [
            keyId,
            new P256VerificationData(authenticatorData, clientDataJSON.clientDataJSONLeft, clientDataJSON.clientDataJSONRight),
            evmAccount,
            p256Signature,
        ], overrides);
    }
    static generateAddEVMAddressWithP256KeyChallenge(evmAccountAddress) {
        // Ensure the address starts with "0x" before slicing it off
        const normalizedAddress = evmAccountAddress.startsWith("0x")
            ? evmAccountAddress.slice(2)
            : evmAccountAddress;
        // Convert address to Uint8Array
        return ok(new TextEncoder().encode(normalizedAddress));
    }
    addEVMAccountWithEVMAccount(evmAccount, overrides) {
        return this.writeToContract("addEVMAccountWithEVMAccount", [evmAccount], overrides);
    }
    removeEVMAccountWithEVMAccount(evmAccount, overrides) {
        return this.writeToContract("removeEVMAccountWithEVMAccount", [evmAccount], overrides);
    }
    withdrawLocalERC20Asset(tokenAddress, overrides) {
        return this.writeToContract("withdrawLocalERC20Asset", [tokenAddress], overrides);
    }
    withdrawNativeAsset(overrides) {
        return this.writeToContract("withdrawNativeAsset", [], overrides);
    }
    name() {
        return ResultAsync.fromPromise(this.contract.getName(), (e) => {
            return this.generateError(e, "Unable to call getName()");
        });
    }
    p256KeyHashes() {
        return ResultAsync.fromPromise(this.contract.getP256KeyHashes(), (e) => {
            return this.generateError(e, "Unable to call getP256KeyHashes()");
        });
    }
    p256Key(keyHash) {
        return ResultAsync.fromPromise(this.contract.getP256Key(keyHash), (e) => {
            return this.generateError(e, "Unable to call getP256KeyHashes()");
        }).map((p256Struct) => {
            return {
                keyId: WebauthnCredentialId(p256Struct.keyId),
                p256PublicKeyComponents: new P256PublicKeyComponents(P256PublicKeyPointX(p256Struct.x), P256PublicKeyPointY(p256Struct.y)),
            };
        });
    }
    evmAccounts() {
        return ResultAsync.fromPromise(this.contract.getEvmAccounts(), (e) => {
            return this.generateError(e, "Unable to call evmAccounts()");
        });
    }
    evmAccountIndex(address) {
        return ResultAsync.fromPromise(this.contract.getEvmAccountIndex(address), (e) => {
            return this.generateError(e, "Unable to call getEvmAccountIndex()");
        });
    }
    hashUsed(hash) {
        return ResultAsync.fromPromise(this.contract.hashUsed(hash), (e) => {
            return this.generateError(e, "Unable to call hashUsed()");
        });
    }
    generateContractSpecificError(msg, e, transaction) {
        return new SnickerdoodleWalletContractError(msg, e, transaction);
    }
};
SnickerdoodleWalletContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String])
], SnickerdoodleWalletContract);
export { SnickerdoodleWalletContract };
//# sourceMappingURL=SnickerdoodleWalletContract.js.map