import { EVMAccountAddress, BlockchainCommonErrors, FarcasterIdGatewayContractError, UnixTimestamp, FarcasterIDGatewayRegisterIdSignature } from "@snickerdoodlelabs/objects";
import { TypedDataField, ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../../implementations/BaseContract.js";
import { IEthersContractError } from "../../implementations/BlockchainErrorMapper.js";
import { ContractOverrides, IFarcasterIdGatewayContract, WrappedTransactionResponse } from "../../interfaces/index.js";
export declare class FarcasterIdGatewayContract extends BaseContract<FarcasterIdGatewayContractError> implements IFarcasterIdGatewayContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer);
    price(extraStorage?: bigint): ResultAsync<bigint, FarcasterIdGatewayContractError | BlockchainCommonErrors>;
    nonces(address: EVMAccountAddress): ResultAsync<bigint, FarcasterIdGatewayContractError | BlockchainCommonErrors>;
    register(recoveryAddress: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | FarcasterIdGatewayContractError>;
    registerWithExtraStorage(recoveryAddress: EVMAccountAddress, extraStorage: bigint, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | FarcasterIdGatewayContractError>;
    registerFor(ownerAddress: EVMAccountAddress, recoveryAddress: EVMAccountAddress, deadline: UnixTimestamp, signature: FarcasterIDGatewayRegisterIdSignature, // EIP-712 'Register' signature from fidOwner obtained from getRegisterSignature()
    overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, FarcasterIdGatewayContractError | BlockchainCommonErrors>;
    registerForWithExtraStorage(ownerAddress: EVMAccountAddress, recoveryAddress: EVMAccountAddress, deadline: UnixTimestamp, signature: FarcasterIDGatewayRegisterIdSignature, // EIP-712 'Register' signature from fidOwner obtained from getRegisterSignature()
    extraStorage: bigint, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, FarcasterIdGatewayContractError | BlockchainCommonErrors>;
    getRegisterSignature(ownerAddress: EVMAccountAddress, recoveryAddress: EVMAccountAddress, nonce: bigint, deadline: UnixTimestamp): ResultAsync<FarcasterIDGatewayRegisterIdSignature, FarcasterIdGatewayContractError | BlockchainCommonErrors>;
    protected removeReadonlyFromReadonlyTypes<T>(obj: T): Record<string, TypedDataField[]>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): FarcasterIdGatewayContractError;
}
//# sourceMappingURL=FarcasterIdGatewayContract.d.ts.map