var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { SIGNED_KEY_REQUEST_VALIDATOR_EIP_712_TYPES, KEY_GATEWAY_EIP_712_TYPES, KEY_GATEWAY_ADDRESS, } from "@farcaster/hub-nodejs";
import { EVMContractAddress, FarcasterKeyGatewayContractError, FarcasterSignedKeyRequestSignature, FarcasterEncodedSignedKeyRequestMetadata, UnexpectedNetworkError, } from "@snickerdoodlelabs/objects";
import { ParamType, ethers } from "ethers";
import { injectable } from "inversify";
import { ResultAsync, errAsync, okAsync } from "neverthrow";
import { BaseContract } from "../../implementations/BaseContract.js";
import { ContractsAbis, SignedKeyRequest, } from "../../interfaces/objects/index.js";
import { FarcasterKeyGatewayAddKeyMessage, FarcasterKeyGatewayAddKeySignatureParams, FarcasterKeyGatewayEIP712Domain } from "../../interfaces/objects/farcaster/index.js";
let FarcasterKeyGatewayContract = class FarcasterKeyGatewayContract extends BaseContract {
    constructor(providerOrSigner) {
        super(providerOrSigner, EVMContractAddress(KEY_GATEWAY_ADDRESS), ContractsAbis.FarcasterKeyGatewayAbi.abi);
        this.providerOrSigner = providerOrSigner;
    }
    nonces(address) {
        return ResultAsync.fromPromise(this.contract.nonces(address), (e) => {
            return this.generateError(e, "Unable to call nonces()");
        });
    }
    add(keyToAdd, encodedMetadata, // obtained from getEncodedSignedKeyRequestMetadata()
    overrides) {
        // Based on the docs, only keyType and metadataType of 1 is supported at the moment
        // https://docs.farcaster.xyz/reference/contracts/reference/key-gateway#add
        return this.assureSigner("add").andThen(() => {
            return this.writeToContract("add", [
                1,
                ethers.hexlify(ethers.toUtf8Bytes(keyToAdd)),
                1,
                ethers.hexlify(ethers.toUtf8Bytes(encodedMetadata)),
            ], overrides);
        });
    }
    // Called by third party on behalf of an fid
    // Called by the owner's EW to sign a 'Register' signature
    // The signature and encodedMetadata for the 'Add' function must first be obtained using the wallet owning the fid via getSignedKeyRequestSignatureAndEncodedMetadata()
    addFor(fidOwnerAddress, keyToAdd, encodedMetadata, deadline, signature, overrides) {
        // Based on the docs, only keyType and metadataType of 1 are supported at the moment
        // https://docs.farcaster.xyz/reference/contracts/reference/key-gateway#addfor
        return this.assureSigner("addFor").andThen(() => {
            return this.writeToContract("addFor", [
                fidOwnerAddress,
                1,
                keyToAdd,
                1,
                encodedMetadata,
                deadline,
                signature,
            ], overrides);
        });
    }
    // Returns the signature params for 'Add' signature to be signed on Farcaster app by the user via signTypedData() (refer to getAddSignature())
    // The encodedMetadata can be obtained from getSignedKeyRequestSignatureAndEncodedMetadata() which is first signed by the EW
    getAddSignatureParams(ownerAddress, keyToAdd, encodedMetadata, deadline) {
        return this.nonces(ownerAddress).map((latestNonce) => {
            const addKeyMessage = new FarcasterKeyGatewayAddKeyMessage(ownerAddress, 1, keyToAdd, 1, encodedMetadata, latestNonce, deadline);
            return new FarcasterKeyGatewayAddKeySignatureParams(new FarcasterKeyGatewayEIP712Domain(), this.removeReadonlyFromReadonlyTypes(KEY_GATEWAY_EIP_712_TYPES.types), addKeyMessage);
        });
    }
    getAddSignature(ownerAddress, keyToAdd, encodedMetadata, deadline) {
        return this.assureSigner("getAddSignature").andThen((signer) => {
            return this.nonces(ownerAddress).andThen((latestNonce) => {
                const addKeyMessage = {
                    owner: ownerAddress,
                    keyType: 1,
                    key: keyToAdd,
                    metadataType: 1,
                    metadata: encodedMetadata,
                    nonce: latestNonce,
                    deadline: deadline,
                };
                return ResultAsync.fromPromise(signer.signTypedData(KEY_GATEWAY_EIP_712_TYPES.domain, this.removeReadonlyFromReadonlyTypes(KEY_GATEWAY_EIP_712_TYPES.types), addKeyMessage), (e) => {
                    return e;
                });
            });
        });
    }
    getSignedKeyRequestSignatureAndEncodedMetadata(ownerFid, ownerEVMAddress, keyToAdd, deadline) {
        return this.assureSigner("getSignedKeyRequestSignatureAndEncodedMetadata").andThen(() => {
            return this.getSignedKeyRequestSignature(ownerFid, keyToAdd, deadline).andThen((metadataSignature) => {
                const metadataStruct = {
                    requestFid: ownerFid,
                    requestSigner: ownerEVMAddress,
                    signature: metadataSignature,
                    deadline: deadline,
                };
                const metadataStructType = ParamType.from({
                    components: [
                        {
                            name: "requestFid",
                            type: "uint256",
                        },
                        {
                            name: "requestSigner",
                            type: "address",
                        },
                        {
                            name: "signature",
                            type: "bytes",
                        },
                        {
                            name: "deadline",
                            type: "uint256",
                        },
                    ],
                    name: "SignedKeyRequestMetadata",
                    type: "tuple",
                });
                if (metadataStructType.components == null) {
                    return errAsync(new UnexpectedNetworkError("fail to encode", "getSignedKeyRequestSignatureAndEncodedMetadata"));
                }
                const encodedMetadataStruct = ethers.AbiCoder.defaultAbiCoder().encode([metadataStructType], [metadataStruct]);
                return okAsync(new SignedKeyRequest(FarcasterSignedKeyRequestSignature(metadataSignature), FarcasterEncodedSignedKeyRequestMetadata(encodedMetadataStruct)));
            });
        });
    }
    // Returns SignedKeyRequestSignature
    getSignedKeyRequestSignature(ownerFid, keyToAdd, // key to be tied to account
    deadline) {
        return this.assureSigner("getSignedKeyRequestSignature").andThen((signer) => {
            //    https://docs.farcaster.xyz/reference/contracts/reference/signed-key-request-validator#signedkeyrequestmetadata-struct
            //    Needs to be a EIP712 signature
            const metadataMessage = {
                requestFid: ownerFid,
                key: keyToAdd,
                deadline: deadline,
            };
            return ResultAsync.fromPromise(signer.signTypedData(SIGNED_KEY_REQUEST_VALIDATOR_EIP_712_TYPES.domain, this.removeReadonlyFromReadonlyTypes(SIGNED_KEY_REQUEST_VALIDATOR_EIP_712_TYPES.types), metadataMessage), (e) => {
                return e;
            });
        });
    }
    removeReadonlyFromReadonlyTypes(obj) {
        return obj;
    }
    generateContractSpecificError(msg, e, transaction) {
        return new FarcasterKeyGatewayContractError(msg, e, transaction);
    }
};
FarcasterKeyGatewayContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object])
], FarcasterKeyGatewayContract);
export { FarcasterKeyGatewayContract };
//# sourceMappingURL=FarcasterKeyGatewayContract.js.map